@@ -141,7 +141,13 @@ errorLocalizer.editmatrix <- function(
 
             w <- sum(weight[adapt])
 
-            if ( w > min(wsol,maxweight) 
+            if (.memfail ){
+              memfail <- TRUE
+              .memfail <- FALSE
+              return(FALSE)
+            }
+
+            if ( w > min(wsol,maxweight)
               || sum(adapt) > maxadapt
               || isObviouslyInfeasible.editmatrix(.E,tol=tol)
                ) return(FALSE)
@@ -165,20 +171,27 @@ errorLocalizer.editmatrix <- function(
             totreat <- totreat[-1]
         },
         choiceRight = {
+            .memfail <- FALSE
             .var <- totreat[1]
-            .E <- eliminate.editmatrix(.E, .var)
+            .E <- tryCatch(
+              eliminate.editmatrix(.E, .var),
+              error=function(e){
+                .memfail <<- TRUE
+                .E 
+              })
             adapt[.var] <- TRUE
             totreat <- totreat[-1]
         },
         .E = E,
         x = x,
-        maxadapt=maxadapt,
-        maxweight=maxweight,
-        totreat = totreat,
-        adapt = adapt,
-        weight = weight,
-        wsol = wsol,
-        tol  = tol
+        maxadapt  = maxadapt,
+        maxweight = maxweight,
+        totreat   = totreat,
+        adapt     = adapt,
+        weight    = weight,
+        wsol      = wsol,
+        tol       = tol,
+        .memfail   = FALSE
     )
     
     # add a searchBest function, currently returns random solution in the case of multiple optima
@@ -235,6 +248,12 @@ errorLocalizer.editarray <- function(
         isSolution = {
             w <- sum(weight[adapt])
 
+            if (.memfail ){
+              memfail <- TRUE
+              .memfail <- FALSE
+              return(FALSE)
+            }
+            
             if ( w > min(wsol,maxweight) || sum(adapt) > maxadapt )  return(FALSE) 
 
             # check feasibility 
@@ -261,8 +280,14 @@ errorLocalizer.editarray <- function(
             .totreat <- .totreat[-1]
         },
         choiceRight = {
+            .memfail <- FALSE
             .var <- .totreat[1]
-            .E <- eliminate.editarray(.E, .var)
+            .E <- tryCatch(
+              eliminate.editarray(.E, .var),
+              error = function(e){
+                .memfail <<- TRUE
+                .E
+              })
             adapt[.var] <- TRUE
             .totreat <- .totreat[-1]
         },
@@ -274,7 +299,8 @@ errorLocalizer.editarray <- function(
         adapt   = adapt,
         weight  = weight,
         wsol    = wsol,
-        ind     = ind
+        ind     = ind,
+        .memfail = FALSE
     )
     # add a searchBest function, currently returns random solution in the case of multiple optima
     with(bt,{
@@ -332,7 +358,12 @@ errorLocalizer.editlist <- function(
     bt <- backtracker(
         isSolution = {
             w <- sum(weight[adapt])
-
+            if (.memfail ){
+              memfail <- TRUE
+              .memfail <- FALSE
+              return(FALSE)
+            }
+            
             if ( w > min(wsol,maxweight) || sum(adapt) > maxadapt )  return(FALSE) 
 
             # check feasibility 
@@ -393,8 +424,14 @@ errorLocalizer.editlist <- function(
             .totreat <- .totreat[-1]
         },
         choiceRight = {
+            .memfail <- FALSE
             .var <- .totreat[1]
-            .E <- eliminate.editlist(.E, .var)
+            .E <- tryCatch(
+              eliminate.editlist(.E, .var),
+              error = function(e){
+                .memfail <<- TRUE
+                .E
+              })
             adapt[.var] <- TRUE
             .totreat <- .totreat[-1]
         },
@@ -408,7 +445,8 @@ errorLocalizer.editlist <- function(
         wsol        = wsol,
         ind         = ind,
         .icat       = icat,
-        .catvar     = catvar
+        .catvar     = catvar,
+        .memfail     = FALSE
     )
     # add a searchBest function, returns random solution when multiple weights are encountered.
     with(bt,{
